# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _repos

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


import delta
import fs

svn_repos_version = _repos.svn_repos_version

svn_repos_find_root_path = _repos.svn_repos_find_root_path

svn_repos_open = _repos.svn_repos_open

svn_repos_create = _repos.svn_repos_create

svn_repos_delete = _repos.svn_repos_delete

svn_repos_fs = _repos.svn_repos_fs

svn_repos_hotcopy = _repos.svn_repos_hotcopy

svn_repos_recover = _repos.svn_repos_recover

svn_repos_recover2 = _repos.svn_repos_recover2

svn_repos_db_logfiles = _repos.svn_repos_db_logfiles

svn_repos_path = _repos.svn_repos_path

svn_repos_db_env = _repos.svn_repos_db_env

svn_repos_conf_dir = _repos.svn_repos_conf_dir

svn_repos_svnserve_conf = _repos.svn_repos_svnserve_conf

svn_repos_lock_dir = _repos.svn_repos_lock_dir

svn_repos_db_lockfile = _repos.svn_repos_db_lockfile

svn_repos_db_logs_lockfile = _repos.svn_repos_db_logs_lockfile

svn_repos_hook_dir = _repos.svn_repos_hook_dir

svn_repos_start_commit_hook = _repos.svn_repos_start_commit_hook

svn_repos_pre_commit_hook = _repos.svn_repos_pre_commit_hook

svn_repos_post_commit_hook = _repos.svn_repos_post_commit_hook

svn_repos_pre_revprop_change_hook = _repos.svn_repos_pre_revprop_change_hook

svn_repos_post_revprop_change_hook = _repos.svn_repos_post_revprop_change_hook

svn_repos_pre_lock_hook = _repos.svn_repos_pre_lock_hook

svn_repos_post_lock_hook = _repos.svn_repos_post_lock_hook

svn_repos_pre_unlock_hook = _repos.svn_repos_pre_unlock_hook

svn_repos_post_unlock_hook = _repos.svn_repos_post_unlock_hook

svn_repos_begin_report = _repos.svn_repos_begin_report

svn_repos_set_path2 = _repos.svn_repos_set_path2

svn_repos_set_path = _repos.svn_repos_set_path

svn_repos_link_path2 = _repos.svn_repos_link_path2

svn_repos_link_path = _repos.svn_repos_link_path

svn_repos_delete_path = _repos.svn_repos_delete_path

svn_repos_finish_report = _repos.svn_repos_finish_report

svn_repos_abort_report = _repos.svn_repos_abort_report

svn_repos_dir_delta = _repos.svn_repos_dir_delta

svn_repos_replay = _repos.svn_repos_replay

svn_repos_get_commit_editor2 = _repos.svn_repos_get_commit_editor2

svn_repos_get_commit_editor = _repos.svn_repos_get_commit_editor

svn_repos_dated_revision = _repos.svn_repos_dated_revision

svn_repos_get_committed_info = _repos.svn_repos_get_committed_info

svn_repos_stat = _repos.svn_repos_stat

svn_repos_history2 = _repos.svn_repos_history2

svn_repos_history = _repos.svn_repos_history

svn_repos_trace_node_locations = _repos.svn_repos_trace_node_locations

svn_repos_get_logs3 = _repos.svn_repos_get_logs3

svn_repos_get_logs2 = _repos.svn_repos_get_logs2

svn_repos_get_logs = _repos.svn_repos_get_logs

svn_repos_get_file_revs = _repos.svn_repos_get_file_revs

svn_repos_fs_commit_txn = _repos.svn_repos_fs_commit_txn

svn_repos_fs_begin_txn_for_commit = _repos.svn_repos_fs_begin_txn_for_commit

svn_repos_fs_begin_txn_for_update = _repos.svn_repos_fs_begin_txn_for_update

svn_repos_fs_lock = _repos.svn_repos_fs_lock

svn_repos_fs_unlock = _repos.svn_repos_fs_unlock

svn_repos_fs_get_locks = _repos.svn_repos_fs_get_locks

svn_repos_fs_change_rev_prop2 = _repos.svn_repos_fs_change_rev_prop2

svn_repos_fs_change_rev_prop = _repos.svn_repos_fs_change_rev_prop

svn_repos_fs_revision_prop = _repos.svn_repos_fs_revision_prop

svn_repos_fs_revision_proplist = _repos.svn_repos_fs_revision_proplist

svn_repos_fs_change_node_prop = _repos.svn_repos_fs_change_node_prop

svn_repos_fs_change_txn_prop = _repos.svn_repos_fs_change_txn_prop
class svn_repos_node_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_repos_node_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_repos_node_t, name)
    def __init__(self): raise RuntimeError, "No constructor defined"
    def __repr__(self):
        return "<%s.%s; proxy of C svn_repos_node_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    __swig_setmethods__["kind"] = _repos.svn_repos_node_t_kind_set
    __swig_getmethods__["kind"] = _repos.svn_repos_node_t_kind_get
    if _newclass:kind = property(_repos.svn_repos_node_t_kind_get, _repos.svn_repos_node_t_kind_set)
    __swig_setmethods__["action"] = _repos.svn_repos_node_t_action_set
    __swig_getmethods__["action"] = _repos.svn_repos_node_t_action_get
    if _newclass:action = property(_repos.svn_repos_node_t_action_get, _repos.svn_repos_node_t_action_set)
    __swig_setmethods__["text_mod"] = _repos.svn_repos_node_t_text_mod_set
    __swig_getmethods__["text_mod"] = _repos.svn_repos_node_t_text_mod_get
    if _newclass:text_mod = property(_repos.svn_repos_node_t_text_mod_get, _repos.svn_repos_node_t_text_mod_set)
    __swig_setmethods__["prop_mod"] = _repos.svn_repos_node_t_prop_mod_set
    __swig_getmethods__["prop_mod"] = _repos.svn_repos_node_t_prop_mod_get
    if _newclass:prop_mod = property(_repos.svn_repos_node_t_prop_mod_get, _repos.svn_repos_node_t_prop_mod_set)
    __swig_setmethods__["name"] = _repos.svn_repos_node_t_name_set
    __swig_getmethods__["name"] = _repos.svn_repos_node_t_name_get
    if _newclass:name = property(_repos.svn_repos_node_t_name_get, _repos.svn_repos_node_t_name_set)
    __swig_setmethods__["copyfrom_rev"] = _repos.svn_repos_node_t_copyfrom_rev_set
    __swig_getmethods__["copyfrom_rev"] = _repos.svn_repos_node_t_copyfrom_rev_get
    if _newclass:copyfrom_rev = property(_repos.svn_repos_node_t_copyfrom_rev_get, _repos.svn_repos_node_t_copyfrom_rev_set)
    __swig_setmethods__["copyfrom_path"] = _repos.svn_repos_node_t_copyfrom_path_set
    __swig_getmethods__["copyfrom_path"] = _repos.svn_repos_node_t_copyfrom_path_get
    if _newclass:copyfrom_path = property(_repos.svn_repos_node_t_copyfrom_path_get, _repos.svn_repos_node_t_copyfrom_path_set)
    __swig_setmethods__["sibling"] = _repos.svn_repos_node_t_sibling_set
    __swig_getmethods__["sibling"] = _repos.svn_repos_node_t_sibling_get
    if _newclass:sibling = property(_repos.svn_repos_node_t_sibling_get, _repos.svn_repos_node_t_sibling_set)
    __swig_setmethods__["child"] = _repos.svn_repos_node_t_child_set
    __swig_getmethods__["child"] = _repos.svn_repos_node_t_child_get
    if _newclass:child = property(_repos.svn_repos_node_t_child_get, _repos.svn_repos_node_t_child_set)
    __swig_setmethods__["parent"] = _repos.svn_repos_node_t_parent_set
    __swig_getmethods__["parent"] = _repos.svn_repos_node_t_parent_get
    if _newclass:parent = property(_repos.svn_repos_node_t_parent_get, _repos.svn_repos_node_t_parent_set)

class svn_repos_node_tPtr(svn_repos_node_t):
    def __init__(self, this):
        _swig_setattr(self, svn_repos_node_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_repos_node_t, 'thisown', 0)
        _swig_setattr(self, svn_repos_node_t,self.__class__,svn_repos_node_t)
_repos.svn_repos_node_t_swigregister(svn_repos_node_tPtr)


svn_repos_node_editor = _repos.svn_repos_node_editor

svn_repos_node_from_baton = _repos.svn_repos_node_from_baton
SVN_REPOS_DUMPFILE_MAGIC_HEADER = _repos.SVN_REPOS_DUMPFILE_MAGIC_HEADER
SVN_REPOS_DUMPFILE_FORMAT_VERSION = _repos.SVN_REPOS_DUMPFILE_FORMAT_VERSION
SVN_REPOS_DUMPFILE_UUID = _repos.SVN_REPOS_DUMPFILE_UUID
SVN_REPOS_DUMPFILE_CONTENT_LENGTH = _repos.SVN_REPOS_DUMPFILE_CONTENT_LENGTH
SVN_REPOS_DUMPFILE_REVISION_NUMBER = _repos.SVN_REPOS_DUMPFILE_REVISION_NUMBER
SVN_REPOS_DUMPFILE_NODE_PATH = _repos.SVN_REPOS_DUMPFILE_NODE_PATH
SVN_REPOS_DUMPFILE_NODE_KIND = _repos.SVN_REPOS_DUMPFILE_NODE_KIND
SVN_REPOS_DUMPFILE_NODE_ACTION = _repos.SVN_REPOS_DUMPFILE_NODE_ACTION
SVN_REPOS_DUMPFILE_NODE_COPYFROM_PATH = _repos.SVN_REPOS_DUMPFILE_NODE_COPYFROM_PATH
SVN_REPOS_DUMPFILE_NODE_COPYFROM_REV = _repos.SVN_REPOS_DUMPFILE_NODE_COPYFROM_REV
SVN_REPOS_DUMPFILE_TEXT_COPY_SOURCE_CHECKSUM = _repos.SVN_REPOS_DUMPFILE_TEXT_COPY_SOURCE_CHECKSUM
SVN_REPOS_DUMPFILE_TEXT_CONTENT_CHECKSUM = _repos.SVN_REPOS_DUMPFILE_TEXT_CONTENT_CHECKSUM
SVN_REPOS_DUMPFILE_PROP_CONTENT_LENGTH = _repos.SVN_REPOS_DUMPFILE_PROP_CONTENT_LENGTH
SVN_REPOS_DUMPFILE_TEXT_CONTENT_LENGTH = _repos.SVN_REPOS_DUMPFILE_TEXT_CONTENT_LENGTH
SVN_REPOS_DUMPFILE_PROP_DELTA = _repos.SVN_REPOS_DUMPFILE_PROP_DELTA
SVN_REPOS_DUMPFILE_TEXT_DELTA = _repos.SVN_REPOS_DUMPFILE_TEXT_DELTA
svn_node_action_change = _repos.svn_node_action_change
svn_node_action_add = _repos.svn_node_action_add
svn_node_action_delete = _repos.svn_node_action_delete
svn_node_action_replace = _repos.svn_node_action_replace
svn_repos_load_uuid_default = _repos.svn_repos_load_uuid_default
svn_repos_load_uuid_ignore = _repos.svn_repos_load_uuid_ignore
svn_repos_load_uuid_force = _repos.svn_repos_load_uuid_force

svn_repos_dump_fs2 = _repos.svn_repos_dump_fs2

svn_repos_dump_fs = _repos.svn_repos_dump_fs

svn_repos_load_fs2 = _repos.svn_repos_load_fs2

svn_repos_load_fs = _repos.svn_repos_load_fs
class svn_repos_parser_fns2_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_repos_parser_fns2_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_repos_parser_fns2_t, name)
    def __init__(self): raise RuntimeError, "No constructor defined"
    def __repr__(self):
        return "<%s.%s; proxy of C svn_repos_parser_fns2_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    __swig_setmethods__["new_revision_record"] = _repos.svn_repos_parser_fns2_t_new_revision_record_set
    __swig_getmethods__["new_revision_record"] = _repos.svn_repos_parser_fns2_t_new_revision_record_get
    if _newclass:new_revision_record = property(_repos.svn_repos_parser_fns2_t_new_revision_record_get, _repos.svn_repos_parser_fns2_t_new_revision_record_set)
    __swig_setmethods__["uuid_record"] = _repos.svn_repos_parser_fns2_t_uuid_record_set
    __swig_getmethods__["uuid_record"] = _repos.svn_repos_parser_fns2_t_uuid_record_get
    if _newclass:uuid_record = property(_repos.svn_repos_parser_fns2_t_uuid_record_get, _repos.svn_repos_parser_fns2_t_uuid_record_set)
    __swig_setmethods__["new_node_record"] = _repos.svn_repos_parser_fns2_t_new_node_record_set
    __swig_getmethods__["new_node_record"] = _repos.svn_repos_parser_fns2_t_new_node_record_get
    if _newclass:new_node_record = property(_repos.svn_repos_parser_fns2_t_new_node_record_get, _repos.svn_repos_parser_fns2_t_new_node_record_set)
    __swig_setmethods__["set_revision_property"] = _repos.svn_repos_parser_fns2_t_set_revision_property_set
    __swig_getmethods__["set_revision_property"] = _repos.svn_repos_parser_fns2_t_set_revision_property_get
    if _newclass:set_revision_property = property(_repos.svn_repos_parser_fns2_t_set_revision_property_get, _repos.svn_repos_parser_fns2_t_set_revision_property_set)
    __swig_setmethods__["set_node_property"] = _repos.svn_repos_parser_fns2_t_set_node_property_set
    __swig_getmethods__["set_node_property"] = _repos.svn_repos_parser_fns2_t_set_node_property_get
    if _newclass:set_node_property = property(_repos.svn_repos_parser_fns2_t_set_node_property_get, _repos.svn_repos_parser_fns2_t_set_node_property_set)
    __swig_setmethods__["delete_node_property"] = _repos.svn_repos_parser_fns2_t_delete_node_property_set
    __swig_getmethods__["delete_node_property"] = _repos.svn_repos_parser_fns2_t_delete_node_property_get
    if _newclass:delete_node_property = property(_repos.svn_repos_parser_fns2_t_delete_node_property_get, _repos.svn_repos_parser_fns2_t_delete_node_property_set)
    __swig_setmethods__["remove_node_props"] = _repos.svn_repos_parser_fns2_t_remove_node_props_set
    __swig_getmethods__["remove_node_props"] = _repos.svn_repos_parser_fns2_t_remove_node_props_get
    if _newclass:remove_node_props = property(_repos.svn_repos_parser_fns2_t_remove_node_props_get, _repos.svn_repos_parser_fns2_t_remove_node_props_set)
    __swig_setmethods__["set_fulltext"] = _repos.svn_repos_parser_fns2_t_set_fulltext_set
    __swig_getmethods__["set_fulltext"] = _repos.svn_repos_parser_fns2_t_set_fulltext_get
    if _newclass:set_fulltext = property(_repos.svn_repos_parser_fns2_t_set_fulltext_get, _repos.svn_repos_parser_fns2_t_set_fulltext_set)
    __swig_setmethods__["apply_textdelta"] = _repos.svn_repos_parser_fns2_t_apply_textdelta_set
    __swig_getmethods__["apply_textdelta"] = _repos.svn_repos_parser_fns2_t_apply_textdelta_get
    if _newclass:apply_textdelta = property(_repos.svn_repos_parser_fns2_t_apply_textdelta_get, _repos.svn_repos_parser_fns2_t_apply_textdelta_set)
    __swig_setmethods__["close_node"] = _repos.svn_repos_parser_fns2_t_close_node_set
    __swig_getmethods__["close_node"] = _repos.svn_repos_parser_fns2_t_close_node_get
    if _newclass:close_node = property(_repos.svn_repos_parser_fns2_t_close_node_get, _repos.svn_repos_parser_fns2_t_close_node_set)
    __swig_setmethods__["close_revision"] = _repos.svn_repos_parser_fns2_t_close_revision_set
    __swig_getmethods__["close_revision"] = _repos.svn_repos_parser_fns2_t_close_revision_get
    if _newclass:close_revision = property(_repos.svn_repos_parser_fns2_t_close_revision_get, _repos.svn_repos_parser_fns2_t_close_revision_set)

class svn_repos_parser_fns2_tPtr(svn_repos_parser_fns2_t):
    def __init__(self, this):
        _swig_setattr(self, svn_repos_parser_fns2_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_repos_parser_fns2_t, 'thisown', 0)
        _swig_setattr(self, svn_repos_parser_fns2_t,self.__class__,svn_repos_parser_fns2_t)
_repos.svn_repos_parser_fns2_t_swigregister(svn_repos_parser_fns2_tPtr)


svn_repos_parse_dumpstream2 = _repos.svn_repos_parse_dumpstream2

svn_repos_get_fs_build_parser2 = _repos.svn_repos_get_fs_build_parser2
class svn_repos_parser_fns_t(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, svn_repos_parser_fns_t, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, svn_repos_parser_fns_t, name)
    def __init__(self): raise RuntimeError, "No constructor defined"
    def __repr__(self):
        return "<%s.%s; proxy of C svn_repos_parser_fns_t instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    __swig_setmethods__["new_revision_record"] = _repos.svn_repos_parser_fns_t_new_revision_record_set
    __swig_getmethods__["new_revision_record"] = _repos.svn_repos_parser_fns_t_new_revision_record_get
    if _newclass:new_revision_record = property(_repos.svn_repos_parser_fns_t_new_revision_record_get, _repos.svn_repos_parser_fns_t_new_revision_record_set)
    __swig_setmethods__["uuid_record"] = _repos.svn_repos_parser_fns_t_uuid_record_set
    __swig_getmethods__["uuid_record"] = _repos.svn_repos_parser_fns_t_uuid_record_get
    if _newclass:uuid_record = property(_repos.svn_repos_parser_fns_t_uuid_record_get, _repos.svn_repos_parser_fns_t_uuid_record_set)
    __swig_setmethods__["new_node_record"] = _repos.svn_repos_parser_fns_t_new_node_record_set
    __swig_getmethods__["new_node_record"] = _repos.svn_repos_parser_fns_t_new_node_record_get
    if _newclass:new_node_record = property(_repos.svn_repos_parser_fns_t_new_node_record_get, _repos.svn_repos_parser_fns_t_new_node_record_set)
    __swig_setmethods__["set_revision_property"] = _repos.svn_repos_parser_fns_t_set_revision_property_set
    __swig_getmethods__["set_revision_property"] = _repos.svn_repos_parser_fns_t_set_revision_property_get
    if _newclass:set_revision_property = property(_repos.svn_repos_parser_fns_t_set_revision_property_get, _repos.svn_repos_parser_fns_t_set_revision_property_set)
    __swig_setmethods__["set_node_property"] = _repos.svn_repos_parser_fns_t_set_node_property_set
    __swig_getmethods__["set_node_property"] = _repos.svn_repos_parser_fns_t_set_node_property_get
    if _newclass:set_node_property = property(_repos.svn_repos_parser_fns_t_set_node_property_get, _repos.svn_repos_parser_fns_t_set_node_property_set)
    __swig_setmethods__["remove_node_props"] = _repos.svn_repos_parser_fns_t_remove_node_props_set
    __swig_getmethods__["remove_node_props"] = _repos.svn_repos_parser_fns_t_remove_node_props_get
    if _newclass:remove_node_props = property(_repos.svn_repos_parser_fns_t_remove_node_props_get, _repos.svn_repos_parser_fns_t_remove_node_props_set)
    __swig_setmethods__["set_fulltext"] = _repos.svn_repos_parser_fns_t_set_fulltext_set
    __swig_getmethods__["set_fulltext"] = _repos.svn_repos_parser_fns_t_set_fulltext_get
    if _newclass:set_fulltext = property(_repos.svn_repos_parser_fns_t_set_fulltext_get, _repos.svn_repos_parser_fns_t_set_fulltext_set)
    __swig_setmethods__["close_node"] = _repos.svn_repos_parser_fns_t_close_node_set
    __swig_getmethods__["close_node"] = _repos.svn_repos_parser_fns_t_close_node_get
    if _newclass:close_node = property(_repos.svn_repos_parser_fns_t_close_node_get, _repos.svn_repos_parser_fns_t_close_node_set)
    __swig_setmethods__["close_revision"] = _repos.svn_repos_parser_fns_t_close_revision_set
    __swig_getmethods__["close_revision"] = _repos.svn_repos_parser_fns_t_close_revision_get
    if _newclass:close_revision = property(_repos.svn_repos_parser_fns_t_close_revision_get, _repos.svn_repos_parser_fns_t_close_revision_set)

class svn_repos_parser_fns_tPtr(svn_repos_parser_fns_t):
    def __init__(self, this):
        _swig_setattr(self, svn_repos_parser_fns_t, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, svn_repos_parser_fns_t, 'thisown', 0)
        _swig_setattr(self, svn_repos_parser_fns_t,self.__class__,svn_repos_parser_fns_t)
_repos.svn_repos_parser_fns_t_swigregister(svn_repos_parser_fns_tPtr)


svn_repos_parse_dumpstream = _repos.svn_repos_parse_dumpstream

svn_repos_get_fs_build_parser = _repos.svn_repos_get_fs_build_parser

